<?php

/**
 * WordPress management panel.
 *
 * @since     0.1
 * @author    @akshitsethi
 * -------------------------------------------------
 */

function mmcs_meta_links( $links, $file ) {

	if ( strpos( $file, 'maintenance-mode-coming-soon.php' ) !== false ) {
		$new_links = array(
			'<a href="http://www.facebook.com/akshitsethi" target="_blank">' . esc_html__( 'Facebook', 'maintenance-mode-coming-soon' ) . '</a>',
			'<a href="http://twitter.com/akshitsethi" target="_blank">' . esc_html__( 'Twitter', 'maintenance-mode-coming-soon' ) . '</a>'
		);

		$links = array_merge( $links, $new_links );
	}

	return $links;

}
add_filter( 'plugin_row_meta', 'mmcs_meta_links', 10, 2 ); // Add plugin meta links


// Menu for the support and about panel
// -------------------------------------------------

function mmcs_add_menu() {

	if( is_admin() && current_user_can( 'manage_options' ) ) {
		// Adding to the plugin panel link to the settings menu
		$menu = add_options_page (
			esc_html__( 'Maintenance Mode & Coming Soon', 'maintenance-mode-coming-soon' ),
			esc_html__( 'Maintenance Mode', 'maintenance-mode-coming-soon' ),
			'manage_options',
			'maintenance_mode_options',
			'mmcs_admin_settings'
		);

		// Loading the JS conditionally
		add_action( 'load-' . $menu, 'mmcs_load_scripts' );
	}

}
add_action( 'admin_menu', 'mmcs_add_menu' );


// Styles & Scripts
// -------------------------------------------------

function mmcs_admin_scripts() {

	wp_register_style( 'mmcs-admin-base', AS_MMCS_URL . '/framework/admin/css/admin.css', false, '0.1' );

	wp_register_script( 'mmcs-webfonts', '//ajax.googleapis.com/ajax/libs/webfont/1.4.7/webfont.js', false, '0.1' );
	wp_register_script( 'mmcs-admin-editor', AS_MMCS_URL . '/framework/admin/js/editor/ace.js', false, '0.1', true );
	wp_register_script( 'mmcs-admin-color', AS_MMCS_URL . '/framework/admin/js/colorpicker/jscolor.js', false, '0.1', true );
	wp_register_script( 'mmcs-admin-base', AS_MMCS_URL . '/framework/admin/js/admin.js', 'jquery', '0.1', true );

	// Styles
	wp_enqueue_style( 'mmcs-admin-base' );

	// Scripts
	wp_enqueue_script( 'mmcs-webfonts' );
	wp_enqueue_script( 'mmcs-admin-editor' );
	wp_enqueue_script( 'mmcs-admin-color' );
	wp_enqueue_script( 'mmcs-admin-base' );

	// Media Uploader
	wp_enqueue_media();

}


// Load
function mmcs_load_scripts() {

	add_action( 'admin_enqueue_scripts', 'mmcs_admin_scripts' );

}


// Notices
// -------------------------------------------------

function mmcs_reg_notice() {

	$class 		= 'notice notice-warning';
	$message 	= '<strong>' . esc_html__( 'Maintenance Mode & Coming Soon', 'maintenance-mode-coming-soon' ) . '</strong> - ' . wp_kses( __( 'Register the plugin to enjoy member exclusive benefits such as priority support, automatic updates, feature requests, discounts and much more. Registration is absolutely free and takes few seconds only. To register, go to the <strong>License</strong> tab in the options panel of the plugin.', 'maintenance-mode-coming-soon' ), array( 'strong' => array() ) ) . '<br/><span style="display: block; margin: 0.5em 0.5em 0 0; clear: both;"><a href="' . admin_url( 'options-general.php?page=maintenance_mode_options' ) . '"><strong>' . esc_html__( 'Register Now', 'maintenance-mode-coming-soon' ) . '</strong></a></span>';

	printf( '<div class="%1$s"><p>%2$s</p></div>', esc_attr( $class ), $message );

}

// Registration Key
$mmcs_reg_key = get_option( 'as_reg_mmcs' );

if ( empty( $mmcs_reg_key ) ) {
	add_action( 'admin_notices', 'mmcs_reg_notice' );
}


// Settings
// -------------------------------------------------

require_once AS_MMCS_PATH . 'framework/admin/settings.php';