<?php

/**
 * Settings page for the plugin
 *
 * @since     0.1
 * @author    @akshitsethi
 * -------------------------------------------------
 */

function mmcs_admin_settings() {

	// Mailchimp Class
	require_once AS_MMCS_PATH . 'framework/public/include/classes/class-mailchimp.php';

	// Google Fonts
	require_once AS_MMCS_PATH . 'framework/admin/include/fonts.php';

	// Get Options
	$options['basic'] 		= get_option( 'mmcs_options_basic' );
	$options['email'] 		= get_option( 'mmcs_options_email' );
	$options['design'] 		= get_option( 'mmcs_options_design' );
	$options['form'] 		= get_option( 'mmcs_options_form' );
	$options['social'] 		= get_option( 'mmcs_options_social' );
	$options['advanced'] 	= get_option( 'mmcs_options_advanced' );

	// Fetch Admin Email
	$admin_email  			= get_option( 'admin_email', '' );

	// Template
	require_once AS_MMCS_PATH . 'framework/admin/views/settings.php';

}


// AJAX Request - Basic Section
function mmcs_ajax_basic() {

	// We are going to store the response in the $response() array
	$response = array(
		'code' 		=> 'success',
		'response' 	=> esc_html__( 'Options have been updated successfully.', 'maintenance-mode-coming-soon' )
	);

	// Filter and Sanitize
	$tmp['status'] 		= isset( $_POST['mmcs_status'] ) ? absint( $_POST['mmcs_status'] ) : '2';
	$tmp['logged'] 		= isset( $_POST['mmcs_showlogged'] ) ? absint( $_POST['mmcs_showlogged'] ) : '2';
	$tmp['exclude_se'] 	= isset( $_POST['mmcs_excludese'] ) ? absint( $_POST['mmcs_excludese'] ) : '2';
	$tmp['branding'] 	= isset( $_POST['mmcs_branding'] ) ? absint( $_POST['mmcs_branding'] ) : '2';

	// Save
	$update_options = array(
		'status'				=> $tmp['status'],
		'title' 				=> sanitize_text_field( $_POST['mmcs_title'] ),
		'header_text' 			=> $_POST['mmcs_header'],
		'secondary_text' 		=> $_POST['mmcs_secondary'],
		'antispam_text' 		=> sanitize_text_field( $_POST['mmcs_antispam'] ),
		'custom_login_url' 		=> sanitize_text_field( $_POST['mmcs_custom_login'] ),
		'show_logged_in' 		=> $tmp['logged'],
		'exclude_se'			=> $tmp['exclude_se'],
		'arrange' 				=> sanitize_text_field( $_POST['mmcs_arrange'] ),
		'analytics' 			=> $_POST['mmcs_analytics'],
		'branding' 				=> $tmp['branding']
	);

	// Update Options + Message
	update_option( 'mmcs_options_basic', $update_options );

	// Header and Output Response
	header( "Content-Type: application/json" );
	echo json_encode( $response );

	// Exit is Required
	exit();

}
add_action( 'wp_ajax_mmcs_basic', 'mmcs_ajax_basic' );


// AJAX Request - Email Section
function mmcs_ajax_email() {

	// We are going to store the response in the $response() array
	$response = array(
		'code' 		=> 'success',
		'response' 	=> esc_html__( 'Options have been updated successfully.', 'maintenance-mode-coming-soon' )
	);

	// Filter and Sanitize
	$tmp['list'] 	= isset( $_POST['mmcs_list'] ) ? sanitize_text_field( $_POST['mmcs_list'] ) : '';

	/**
	 * If the API Key is removed, we should remove the transient also.
	 * -------------------------------------------------
	 */

	$tmp['api'] 	= sanitize_text_field( $_POST['mmcs_api'] );

	// Remove Transient
	delete_transient( 'mmcs_email_list' );

	// Save
	$update_options 		= array(
		'mailchimp_api'			=> $tmp['api'],
		'mailchimp_list' 		=> $tmp['list'], 
		'message_noemail' 		=> sanitize_text_field( $_POST['mmcs_message_noemail'] ),
		'message_subscribed' 	=> sanitize_text_field( $_POST['mmcs_message_subscribed'] ),
		'message_wrong' 		=> sanitize_text_field( $_POST['mmcs_message_wrong'] ),
		'message_done' 			=> sanitize_text_field( $_POST['mmcs_message_done'] )
	);

	// Update Options + Message
	update_option( 'mmcs_options_email', $update_options );

	// Header and Output Response
	header( "Content-Type: application/json" );
	echo json_encode( $response );

	// Exit is Required
	exit();

}
add_action( 'wp_ajax_mmcs_email', 'mmcs_ajax_email' );


// AJAX Request - Design Section
function mmcs_ajax_design() {

	// We are going to store the response in the $response() array
	$response = array(
		'code' 		=> 'success',
		'response' 	=> esc_html__( 'Options have been updated successfully.', 'maintenance-mode-coming-soon' )
	);

	// Filter and Sanitize
	$tmp['overlay'] = isset( $_POST['mmcs_overlay'] ) ? absint( $_POST['mmcs_overlay'] ) : '2';

	// Save
	$update_options = array(
		'logo'						=> sanitize_text_field( $_POST['mmcs_logo'] ),
		'favicon'					=> sanitize_text_field( $_POST['mmcs_favicon'] ),
		'bg_cover' 					=> sanitize_text_field( $_POST['mmcs_bg'] ),
		'content_overlay' 			=> $tmp['overlay'],
		'logo_height' 				=> absint( $_POST['mmcs_logo_height'] ),
		'content_overlay_style' 	=> sanitize_text_field( $_POST['mmcs_overlay_style'] ),
		'content_overlay_opacity' 	=> sanitize_text_field( $_POST['mmcs_overlay_opacity'] ),
		'content_margin'			=> absint( $_POST['mmcs_margin'] ),
		'content_padding'			=> absint( $_POST['mmcs_padding'] ),
		'content_width'				=> absint( $_POST['mmcs_width'] ),
		'content_border_size' 		=> absint( $_POST['mmcs_border_size'] ),
		'content_border_color' 		=> sanitize_text_field( $_POST['mmcs_border_color'] ),
		'bg_color' 					=> sanitize_text_field( $_POST['mmcs_color'] ),
		'content_color' 			=> sanitize_text_field( $_POST['mmcs_content_color'] ),
		'content_position'			=> sanitize_text_field( $_POST['mmcs_position'] ),
		'content_alignment'			=> sanitize_text_field( $_POST['mmcs_alignment'] ),
		'header_font' 				=> sanitize_text_field( $_POST['mmcs_header_font'] ),
		'secondary_font' 			=> sanitize_text_field( $_POST['mmcs_secondary_font'] ),
		'header_font_size' 			=> absint( $_POST['mmcs_header_size'] ),
		'secondary_font_size' 		=> absint( $_POST['mmcs_secondary_size'] ),
		'header_font_lh' 			=> absint( $_POST['mmcs_header_lh'] ),
		'secondary_font_lh' 		=> absint( $_POST['mmcs_secondary_lh'] ),
		'header_font_style' 		=> sanitize_text_field( $_POST['mmcs_header_style'] ),
		'secondary_font_style' 		=> sanitize_text_field( $_POST['mmcs_secondary_style'] ),
		'header_font_color' 		=> sanitize_text_field( $_POST['mmcs_header_color'] ),
		'secondary_font_color' 		=> sanitize_text_field( $_POST['mmcs_secondary_color'] ),
		'antispam_font_size' 		=> absint( $_POST['mmcs_antispam_size'] ),
		'antispam_font_lh' 			=> absint( $_POST['mmcs_antispam_lh'] ),
		'antispam_font_color' 		=> sanitize_text_field( $_POST['mmcs_antispam_color'] )
	);

	// Update Options + Message
	update_option( 'mmcs_options_design', $update_options );

	// Header and Output Response
	header( "Content-Type: application/json" );
	echo json_encode( $response );

	// Exit is Required
	exit();

}
add_action( 'wp_ajax_mmcs_design', 'mmcs_ajax_design' );


// AJAX Request - Form Section
function mmcs_ajax_form() {

	// We are going to store the response in the $response() array
	$response = array(
		'code' 		=> 'success',
		'response' 	=> esc_html__( 'Options have been updated successfully.', 'maintenance-mode-coming-soon' )
	);

	// Filter and Sanitize
	$tmp['form_styles'] = isset( $_POST['mmcs_ignore_styles'] ) ? absint( $_POST['mmcs_ignore_styles'] ) : '2';
	$tmp['ajax_submit'] = isset( $_POST['mmcs_ajax_submit'] ) ? absint( $_POST['mmcs_ajax_submit'] ) : '2';

	// Save
	$update_options = array(
		'input_text' 			=> sanitize_text_field( $_POST['mmcs_input_text'] ),
		'button_text' 			=> sanitize_text_field( $_POST['mmcs_button_text'] ),
		'ignore_form_styles' 	=> $tmp['form_styles'],
		'ajax_submit' 			=> $tmp['ajax_submit'],
		'input_font'			=> sanitize_text_field( $_POST['mmcs_input_font'] ),
		'button_font' 			=> sanitize_text_field( $_POST['mmcs_button_font'] ),
		'input_font_size'		=> absint( $_POST['mmcs_input_size'] ),
		'button_font_size'		=> absint( $_POST['mmcs_button_size'] ),
		'input_font_lh' 		=> absint( $_POST['mmcs_input_lh'] ),
		'button_font_lh' 		=> absint( $_POST['mmcs_button_lh'] ),
		'input_font_color'		=> sanitize_text_field( $_POST['mmcs_input_color'] ),
		'button_font_color'		=> sanitize_text_field( $_POST['mmcs_button_color'] ),
		'input_bg'				=> sanitize_text_field( $_POST['mmcs_input_bg'] ),
		'button_bg'				=> sanitize_text_field( $_POST['mmcs_button_bg'] ),
		'input_bg_hover'		=> sanitize_text_field( $_POST['mmcs_input_bg_hover'] ),
		'button_bg_hover'		=> sanitize_text_field( $_POST['mmcs_button_bg_hover'] ),
		'input_border'			=> sanitize_text_field( $_POST['mmcs_input_border'] ),
		'button_border'			=> sanitize_text_field( $_POST['mmcs_button_border'] ),
		'input_border_hover'	=> sanitize_text_field( $_POST['mmcs_input_border_hover'] ),
		'button_border_hover'	=> sanitize_text_field( $_POST['mmcs_button_border_hover'] ),
		'success_background'	=> sanitize_text_field( $_POST['mmcs_success_bg'] ),
		'success_color'			=> sanitize_text_field( $_POST['mmcs_success_color'] ),
		'error_background'		=> sanitize_text_field( $_POST['mmcs_error_bg'] ),
		'error_color'			=> sanitize_text_field( $_POST['mmcs_error_color'] )
	);

	// Update Options + Message
	update_option( 'mmcs_options_form', $update_options );

	// Header and Output Response
	header( "Content-Type: application/json" );
	echo json_encode( $response );

	// Exit is Required
	exit();

}
add_action( 'wp_ajax_mmcs_form', 'mmcs_ajax_form' );


// AJAX Request - Social Section
function mmcs_ajax_social() {

	// We are going to store the response in the $response() array
	$response = array(
		'code' 		=> 'success',
		'response' 	=> esc_html__( 'Options have been updated successfully.', 'maintenance-mode-coming-soon' ),
		'html' 		=> ''
	);

	// Social Networks
	$social_networks = array(
		'500px' 				=> '500px',
		'amazon' 				=> 'Amazon',
		'android' 				=> 'Android',
		'angellist' 			=> 'AngelList',
		'apple' 				=> 'Apple',
		'behance' 				=> 'Behance',
		'bitbucket' 			=> 'BitBucket',
		'bitcoin' 				=> 'Bitcoin',
		'buysellads' 			=> 'BuySellAds',
		'delicious' 			=> 'Delicious',
		'deviantart' 			=> 'DeviantArt',
		'digg' 					=> 'Digg',
		'dribbble' 				=> 'Dribbble',
		'dropbox' 				=> 'Dropbox',
		'etsy' 					=> 'Etsy',
		'facebook' 				=> 'Facebook',
		'flickr' 				=> 'Flickr',
		'foursquare' 			=> 'FourSquare',
		'github-alt' 			=> 'GitHub',
		'google' 				=> 'Google',
		'google-plus' 			=> 'Google+',
		'imdb' 					=> 'IMDB',
		'instagram' 			=> 'Instagram',
		'lastfm' 				=> 'Last.fm',
		'linkedin' 				=> 'LinkedIn',
		'medium' 				=> 'Medium',
		'meetup' 				=> 'Meetup',
		'mixcloud' 				=> 'MixCloud',
		'paypal' 				=> 'PayPal',
		'pinterest' 			=> 'Pinterest',
		'product-hunt' 			=> 'ProductHunt',
		'quora' 				=> 'Quora',
		'reddit' 				=> 'Reddit',
		'scribd' 				=> 'Scribd',
		'skype' 				=> 'Skype',
		'slack' 				=> 'Slack',
		'slideshare' 			=> 'SlideShare',
		'snapchat' 				=> 'SnapChat',
		'soundcloud' 			=> 'SoundCloud',
		'spotify' 				=> 'Spotify',
		'stack-overflow' 		=> 'StackOverflow',
		'stumbleupon' 			=> 'StumbleUpon',
		'telegram' 				=> 'Telegram',
		'trello' 				=> 'Trello',
		'tripadvisor' 			=> 'TripAdvisor',
		'tumblr' 				=> 'Tumblr',
		'twitch' 				=> 'Twitch',
		'twitter' 				=> 'Twitter',
		'vimeo' 				=> 'Vimeo',
		'vine' 					=> 'Vine',
		'vk' 					=> 'VK',
		'wechat' 				=> 'WeChat',
		'weibo' 				=> 'Weibo',
		'whatsapp' 				=> 'WhatsApp',
		'wikipedia-w' 			=> 'Wikipedia',
		'wordpress' 			=> 'WordPress',
		'xing' 					=> 'Xing',
		'yahoo' 				=> 'Yahoo',
		'youtube-play' 			=> 'YouTube'
	);

	// Filter and Sanitize
	foreach ( $social_networks as $key => $value ) {
		$update_options[$key] = sanitize_text_field( $_POST['mmcs_social_' . $key] );
	}

	$update_options['link_color'] 	= sanitize_text_field( $_POST['mmcs_social_link'] );
	$update_options['link_hover'] 	= sanitize_text_field( $_POST['mmcs_social_hover'] );
	$update_options['icon_size'] 	= absint( $_POST['mmcs_social_size'] );
	$update_options['link_target'] 	= sanitize_text_field( $_POST['mmcs_social_target'] );
	$update_options['arrange'] 		= sanitize_text_field( $_POST['mmcs_social_arrange'] );

	// Update Options + Message
	update_option( 'mmcs_options_social', $update_options );

	// Send the new code for icons preview back to the application
	// Open the array
	if ( isset( $update_options['arrange'] ) && '' != $update_options['arrange'] ) {
		$social_arrange = explode( ',', $update_options['arrange'] );

		// Loop
		foreach ( $social_arrange as $single_item ) {
			if ( ! empty( $update_options[$single_item] ) ) {
				$response['html'] .= '<li><i class="fa fa-fw fa-' . $single_item . '"></i></li>';
			}
		}
	}

	// Header and Output Response
	header( "Content-Type: application/json" );
	echo json_encode( $response );

	// Exit is Required
	exit();

}
add_action( 'wp_ajax_mmcs_social', 'mmcs_ajax_social' );


// AJAX Request - Advanced Section
function mmcs_ajax_advanced() {

	// We are going to store the response in the $response() array
	$response = array(
		'code' 		=> 'success',
		'response' 	=> esc_html__( 'Options have been updated successfully.', 'maintenance-mode-coming-soon' )
	);

	// Filter and Sanitize
	$tmp['disabled'] 	= isset( $_POST['mmcs_disable'] ) ? absint( $_POST['mmcs_disable'] ) : '2';
	$tmp['html'] 		= ( isset( $_POST['mmcs_html'] ) && ! empty( $_POST['mmcs_html'] ) ) ? $_POST['mmcs_html'] : '';
	$tmp['css'] 		= ( isset( $_POST['mmcs_css'] ) && ! empty( $_POST['mmcs_css'] ) ) ? $_POST['mmcs_css'] : '';

	// Update Options
	$update_options = array(
		'disable_settings' 		=> $tmp['disabled'],
		'custom_html'			=> $tmp['html'], // No sanitization
		'custom_css'			=> $tmp['css']  // Giving full freedom to them :)
	);

	// Update Options + Message
	update_option( 'mmcs_options_advanced', $update_options );

	// Header and Output Response
	header( "Content-Type: application/json" );
	echo json_encode( $response );

	// Exit is Required
	exit();

}
add_action( 'wp_ajax_mmcs_advanced', 'mmcs_ajax_advanced' );


// AJAX Request - User Support
function mmcs_ajax_support() {

	// We are going to store the response in the $response() array
	$response = array(
		'code' 		=> 'error',
		'response' 	=> esc_html__( 'Please fill in both the fields to create your support ticket.', 'maintenance-mode-coming-soon' )
	);

	// Filter and Sanitize
	if ( ! empty( $_POST['as_support_email'] ) && ! empty( $_POST['as_support_issue'] ) ) {
		$admin_email 	= sanitize_text_field( $_POST['as_support_email'] );
		$issue 			= $_POST['as_support_issue'];

		$subject 		= '[Maintenance Mode Ticket][version ' . AS_MMCS_VERSION . '] by ' . $admin_email;
		$body 			= "Email: $admin_email \r\nIssue: $issue";
		$headers 		= 'From: ' . $admin_email . "\r\n" . 'Reply-To: ' . $admin_email;

		// Sending the mail to the support email
		if ( true === wp_mail( 'hi@akshitsethi.com', $subject, $body, $headers ) ) {
			// Success Response
			$response = array(
				'code' 		=> 'success',
				'response' 	=> esc_html__( 'I have received your support ticket and will get back to you shortly!', 'maintenance-mode-coming-soon' )
			);
		} else {
			// Failure Response
			$response = array(
				'code' 		=> 'error',
				'response' 	=> esc_html__( 'There was an error creating the support ticket. You can try again later or send me an email directly at hi@akshitsethi.com', 'maintenance-mode-coming-soon' )
			);
		}
	}

	// Header and Output Response
	header( "Content-Type: application/json" );
	echo json_encode( $response );

	// Exit is Required
	exit();

}
add_action( 'wp_ajax_mmcs_support', 'mmcs_ajax_support' );


// AJAX Request - Email List
function mmcs_ajax_email_list() {

	// Mailchimp Class
	require_once AS_MMCS_PATH . 'framework/public/include/classes/class-mailchimp.php';

	// Email Option
	$email_data = get_option( 'mmcs_options_email' );

	// We are going to store the response in the $response() array
	$response = array(
		'code' 		=> 'error',
		'response' 	=> esc_html__( 'Please provide your MailChimp API in the above field before making the request again.', 'maintenance-mode-coming-soon' ),
		'help' 		=> esc_html__( 'Provide your MailChimp API key in the above field and click on `Refresh`. Your lists will appear over here.', 'maintenance-mode-coming-soon' ),
		'html' 		=> ''
	);

	// Filter and Sanitize
	// Checking for the API key
	if ( isset( $_POST['as_email_api'] ) ) {
		// API Key
		$email_api = sanitize_text_field( $_POST['as_email_api'] );

		if ( ! empty( $email_api ) ) {
			// Grabbing Lists
			$api 	= new As_MailChimp( $email_api );
			$lists 	= $api->call( 'lists/list',
				array (
	        		'apikey' => $email_api
	        	)
			);

			if ( ! $lists ) {
				$response['help'] = esc_html__( 'There was an error communicating with the MailChimp server. Please make sure that the API Key used is correct and try again.', 'maintenance-mode-coming-soon' );
			} else if ( $lists['total'] == 0 ) {
				$response['help'] = esc_html__( 'It seems that there is no list created for this account. Why not create one on the MailChimp website and then try here.', 'maintenance-mode-coming-soon' );
			} else {
				// Success
				$response['code'] 		= 'success';
				$response['response'] 	= esc_html__( 'Your lists have been fetched from MailChimp. Please select the list for saving your subscribers data and click on "Save Changes".', 'maintenance-mode-coming-soon' );
				$response['help'] 		= esc_html__( 'Select your MailChimp list in which you would like to store the subscribers data.', 'maintenance-mode-coming-soon' );
				$response['html'] .= '<select name="mmcs_list" id="mmcs_list">';

				foreach ( $lists['data'] as $single_list ) {
					$response['html'] .= '<option value="' . $single_list['id'] . '"' . selected( $single_list['id'], $email_data['mailchimp_list'], false ) . '>' . $single_list['name'].'</option>';
				}

				$response['html'] .= '</select>';

				// Set Transient
				// Cache for 365 days
				set_transient( 'mmcs_email_list', $response['html'] . '<p class="as-form-help-block">' . $response['help'] . '</p>', 60 * 60 * 24 * 365 );
			}
		} else {
			$response['help'] = esc_html__( 'Provide your MailChimp API key in the above field and click on `Refresh`. Your lists will appear over here.', 'maintenance-mode-coming-soon' );
		}
	}

	// Header and Output Response
	header( "Content-Type: application/json" );
	echo json_encode( $response );

	// Exit is Required
	exit();

}
add_action( 'wp_ajax_mmcs_email_list', 'mmcs_ajax_email_list' );


// AJAX : Preview
function mmcs_preview() {

	// Options - Database
	$options['basic'] 		= get_option( 'mmcs_options_basic' );
	$options['email'] 		= get_option( 'mmcs_options_email' );
	$options['design'] 		= get_option( 'mmcs_options_design' );
	$options['form'] 		= get_option( 'mmcs_options_form' );
	$options['social'] 		= get_option( 'mmcs_options_social' );
	$options['advanced'] 	= get_option( 'mmcs_options_advanced' );

	// Render Template
	mmcs_render_template( $options );

	// Exit is Required
	exit();

}
add_action( 'wp_ajax_mmcs_ajax_preview', 'mmcs_preview' );


// AJAX : Registration
function mmcs_register() {

	// Process
	// -------------------------------------------------
	// We are going to store the response in the $response() array

	$response = array(
		'type' 		=> 'error',
		'message' 	=> esc_html__( 'This seems like an invalid request for registration. Please try again after some time.', 'maintenance-mode-coming-soon' )
	);

	// Filter and Sanitize
	if ( ! empty( $_POST['as_email'] ) && ! empty( $_POST['as_website'] ) && ! empty( $_POST['as_product'] ) ) {
		$input['email'] 	= esc_html( $_POST['as_email'] );
		$input['website'] 	= esc_html( $_POST['as_website'] );
		$input['product'] 	= esc_html( $_POST['as_product'] );

		if ( ! empty( $input['email'] ) && ! empty( $input['website'] ) && ! empty( $input['product'] ) ) {
			$remote = wp_remote_get( 'http://www.akshitsethi.com/api/license.php?r=register_product&email=' . $input['email'] . '&website=' . $input['website'] . '&product=' . $input['product'] );

			if ( ! is_wp_error( $remote ) ) {
				$response = json_decode( $remote['body'], TRUE );

				if ( 'success' == $response['type'] && ( '200' == $response['code'] || '400' == $response['code'] ) ) {
					$key = esc_html( $response['key'] );

					// Update Database
					update_option( 'as_reg_mmcs', $key );
				}
			}
		}
	}

	// Header and Output Response
	header( "Content-Type: application/json" );
	echo json_encode( $response );

	// Exit is Required
	exit();

}
add_action( 'wp_ajax_mmcs_ajax_register', 'mmcs_register' );